==> ugene_33.0+dfsg.orig.tar.xz: ugene-33.0/src/plugins/external_tool_support/src/blast/PrepareInputFastaFilesTask.h <==
/**
 * UGENE - Integrated Bioinformatics Tools.
 * Copyright (C) 2008-2019 UniPro <ugene@unipro.ru>
 * http://ugene.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 */

#ifndef _U2_PREPARE_INPUT_FASTA_FILES_TASK_H_
#define _U2_PREPARE_INPUT_FASTA_FILES_TASK_H_

#include <U2Core/Task.h>

namespace U2 {

class PrepareInputFastaFilesTask : public Task {
    Q_OBJECT
public:
    PrepareInputFastaFilesTask(const QStringList &inputFiles, const QString &tempDir);

    QStringList getFastaFiles() const;
    QStringList getTempFiles() const;

private:
    void prepare();
    QList<Task *> onSubTaskFinished(Task *subTask);

    QString getBestFormatId(const QString &filePath);
    bool isFilePathAcceptable(const QString &filePath) const;
    QString getFixedFileName(const QString &filePath) const;

    const QStringList inputFiles;
    const QString tempDir;

    QStringList fastaFiles;
    QStringList tempFiles;
};

}   // namespace U2

#endif // _U2_PREPARE_INPUT_FASTA_FILES_TASK_H_

==> ugene_49.1+dfsg.orig.tar.xz: ugene-49.1/src/plugins/external_tool_support/src/blast/PrepareInputFastaFilesTask.h <==
/**
 * UGENE - Integrated Bioinformatics Tools.
 * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
 * http://ugene.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 */

#pragma once

#include <U2Core/Task.h>

namespace U2 {

class PrepareInputFastaFilesTask : public Task {
    Q_OBJECT
public:
    PrepareInputFastaFilesTask(const QStringList& inputFiles, const QString& tempDir);

    QStringList getFastaFiles() const;
    QStringList getTempFiles() const;

private:
    void prepare() override;
    QList<Task*> onSubTaskFinished(Task* subTask) override;

    QString getBestFormatId(const QString& filePath);
    bool isFilePathAcceptable(const QString& filePath) const;
    QString getFixedFileName(const QString& filePath) const;

    const QStringList inputFiles;
    const QString tempDir;

    QStringList fastaFiles;
    QStringList tempFiles;
};

}  // namespace U2
